==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaDzOOdplatnosci.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DecyzjaDzOOdplatnosci extends GenericDPSObject {
    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long mieszkaniecId;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.KTO_WYDAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ktoWydalId;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWydania;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date obowiazujeOd;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date obowiazujeDo;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.MIESZKANIEC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.KTO_WYDAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKtoWydalId() {
        return ktoWydalId;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.KTO_WYDAL_ID
     *
     * @param ktoWydalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKtoWydalId(Long ktoWydalId) {
        this.ktoWydalId = ktoWydalId;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.DATA_WYDANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getObowiazujeOd() {
        return obowiazujeOd;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_OD
     *
     * @param obowiazujeOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setObowiazujeOd(Date obowiazujeOd) {
        this.obowiazujeOd = obowiazujeOd;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getObowiazujeDo() {
        return obowiazujeDo;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_DO
     *
     * @param obowiazujeDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setObowiazujeDo(Date obowiazujeDo) {
        this.obowiazujeDo = obowiazujeDo;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaDzOOdplatnosci other = (DecyzjaDzOOdplatnosci) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()))
            && (this.getKtoWydalId() == null ? other.getKtoWydalId() == null : this.getKtoWydalId().equals(other.getKtoWydalId()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getObowiazujeOd() == null ? other.getObowiazujeOd() == null : this.getObowiazujeOd().equals(other.getObowiazujeOd()))
            && (this.getObowiazujeDo() == null ? other.getObowiazujeDo() == null : this.getObowiazujeDo().equals(other.getObowiazujeDo()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        result = prime * result + ((getKtoWydalId() == null) ? 0 : getKtoWydalId().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getObowiazujeOd() == null) ? 0 : getObowiazujeOd().hashCode());
        result = prime * result + ((getObowiazujeDo() == null) ? 0 : getObowiazujeDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append(", ktoWydalId=").append(ktoWydalId);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", nr=").append(nr);
        sb.append(", obowiazujeOd=").append(obowiazujeOd);
        sb.append(", obowiazujeDo=").append(obowiazujeDo);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaDzOOdplatnosci.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DecyzjaDzOOdplatnosci extends GenericDPSObject {
    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long mieszkaniecId;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.KTO_WYDAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ktoWydalId;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWydania;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date obowiazujeOd;

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date obowiazujeDo;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.MIESZKANIEC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.KTO_WYDAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKtoWydalId() {
        return ktoWydalId;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.KTO_WYDAL_ID
     *
     * @param ktoWydalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKtoWydalId(Long ktoWydalId) {
        this.ktoWydalId = ktoWydalId;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.DATA_WYDANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getObowiazujeOd() {
        return obowiazujeOd;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_OD
     *
     * @param obowiazujeOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setObowiazujeOd(Date obowiazujeOd) {
        this.obowiazujeOd = obowiazujeOd;
    }

    /**
     * @return DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getObowiazujeDo() {
        return obowiazujeDo;
    }

    /**
     * DECYZJA_DZ_O_ODPLATNOSCI.OBOWIAZUJE_DO
     *
     * @param obowiazujeDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setObowiazujeDo(Date obowiazujeDo) {
        this.obowiazujeDo = obowiazujeDo;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaDzOOdplatnosci other = (DecyzjaDzOOdplatnosci) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()))
            && (this.getKtoWydalId() == null ? other.getKtoWydalId() == null : this.getKtoWydalId().equals(other.getKtoWydalId()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getObowiazujeOd() == null ? other.getObowiazujeOd() == null : this.getObowiazujeOd().equals(other.getObowiazujeOd()))
            && (this.getObowiazujeDo() == null ? other.getObowiazujeDo() == null : this.getObowiazujeDo().equals(other.getObowiazujeDo()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        result = prime * result + ((getKtoWydalId() == null) ? 0 : getKtoWydalId().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getObowiazujeOd() == null) ? 0 : getObowiazujeOd().hashCode());
        result = prime * result + ((getObowiazujeDo() == null) ? 0 : getObowiazujeDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append(", ktoWydalId=").append(ktoWydalId);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", nr=").append(nr);
        sb.append(", obowiazujeOd=").append(obowiazujeOd);
        sb.append(", obowiazujeDo=").append(obowiazujeDo);
        sb.append("]");
        return sb.toString();
    }
}
